@@ -1,35 +1,19 @@
-/****************************************************************************
-**
-** Copyright (C) 2002-2003 Tim Jansen <tim@tjansen.de>
-** Copyright (C) 2007-2008 Urs Wolfer <uwolfer @ kde.org>
-**
-** This file is part of KDE.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; see the file COPYING. If not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-** Boston, MA 02110-1301, USA.
-**
-****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002-2003 Tim Jansen <tim@tjansen.de>
+    SPDX-FileCopyrightText: 2007-2008 Urs Wolfer <uwolfer@kde.org>
+    SPDX-FileCopyrightText: 2021 Rafał Lalik <rafallalik@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef REMOTEVIEW_H
 #define REMOTEVIEW_H
 
 #ifndef QTONLY
-    #include <KWallet/KWallet>
-    #include "krdccore_export.h"
+#include "krdccore_export.h"
+#include <KWallet>
 #else
-    #define KRDCCORE_EXPORT
+#define KRDCCORE_EXPORT
 #endif
 
 #include <QUrl>
@@ -59,53 +43,52 @@ class KRDCCORE_EXPORT RemoteView : public QWidget
     Q_OBJECT
 
 public:
-
     enum Quality {
         Unknown,
         High,
         Medium,
-        Low
+        Low,
     };
     Q_ENUM(Quality)
 
     /**
-    * Describes the state of a local cursor, if there is such a concept in the backend.
-    * With local cursors, there are two cursors: the cursor on the local machine (client),
-    * and the cursor on the remote machine (server). Because there is usually some lag,
-    * some backends show both cursors simultaneously. In the VNC backend the local cursor
-    * is a dot and the remote cursor is the 'real' cursor, usually an arrow.
-    */
+     * Describes the state of a local cursor, if there is such a concept in the backend.
+     * With local cursors, there are two cursors: the cursor on the local machine (client),
+     * and the cursor on the remote machine (server). Because there is usually some lag,
+     * some backends show both cursors simultaneously. In the VNC backend the local cursor
+     * is a dot and the remote cursor is the 'real' cursor, usually an arrow.
+     */
 
     enum LocalCursorState {
-        CursorOn,  ///< Always show local cursor based on remote one (or fallback to default).
+        CursorOn, ///< Always show local cursor based on remote one (or fallback to default).
         CursorOff, ///< Never show local cursor, only the remote one.
         /// Try to measure the lag and enable the local cursor if the latency is too high.
-        CursorAuto
+        CursorAuto,
     };
     Q_ENUM(LocalCursorState)
 
     /**
-    * State of the connection. The state of the connection is returned
-    * by @ref RemoteView::status().
-    *
-    * Not every state transition is allowed. You are only allowed to transition
-    * a state to the following state, with three exceptions:
-    * @li You can move from every state directly to Disconnected
-    * @li You can move from every state except Disconnected to
-    *     Disconnecting
-    * @li You can move from Disconnected to Connecting
-    *
-    * @ref RemoteView::setStatus() will follow this rules for you.
-    * (If you add/remove a state here, you must adapt it)
-    */
+     * State of the connection. The state of the connection is returned
+     * by @ref RemoteView::status().
+     *
+     * Not every state transition is allowed. You are only allowed to transition
+     * a state to the following state, with three exceptions:
+     * @li You can move from every state directly to Disconnected
+     * @li You can move from every state except Disconnected to
+     *     Disconnecting
+     * @li You can move from Disconnected to Connecting
+     *
+     * @ref RemoteView::setStatus() will follow this rules for you.
+     * (If you add/remove a state here, you must adapt it)
+     */
 
     enum RemoteStatus {
-        Connecting     = 0,
+        Connecting = 0,
         Authenticating = 1,
-        Preparing      = 2,
-        Connected      = 3,
-        Disconnecting  = -1,
-        Disconnected   = -2
+        Preparing = 2,
+        Connected = 3,
+        Disconnecting = -1,
+        Disconnected = -2,
     };
     Q_ENUM(RemoteStatus)
 
@@ -118,7 +101,7 @@ public:
         Name,
         NoServer,
         ServerBlocked,
-        Authentication
+        Authentication,
     };
     Q_ENUM(ErrorCode)
 
@@ -258,7 +241,7 @@ public:
     /**
      * Returns the current host preferences of this view.
      */
-    virtual HostPreferences* hostPreferences() = 0;
+    virtual HostPreferences *hostPreferences() = 0;
 #endif
 
     /**
@@ -284,6 +267,16 @@ public Q_SLOTS:
      */
     virtual void enableScaling(bool scale);
 
+    /**
+     * Sets scaling factor for the view. If remote view has width R and
+     * the window has width W, then scaling factor (float, range 0-1) set the
+     * remote view width A to be: A = (R-W)*factor + W. For factor = 0, A=W,
+     * so no scalling, for factor=1, A=R.
+     *
+     * @param factor scaling factor in the range 0-1
+     */
+    virtual void setScaleFactor(float factor);
+
     /**
      * Enables/disables the view-only mode.
      * Ignored if @ref supportsScaling() is false.
@@ -319,6 +312,9 @@ public Q_SLOTS:
     /**
      * Called when the visible place changed so remote
      * view can resize itself.
+     *
+     * @param w width of the remote view
+     * @param h height of the remote view
      */
     virtual void scaleResize(int w, int h);
 
@@ -354,7 +350,7 @@ Q_SIGNALS:
     /**
      * Emitted when the status of the view changed.
      * @param s the new status
-        */
+     */
     void statusChanged(RemoteView::RemoteStatus s);
 
     /**
@@ -406,6 +402,7 @@ protected:
     bool m_scale;
     bool m_keyboardIsGrabbed;
     QUrl m_url;
+    qreal m_factor;
 
 #ifndef QTONLY
     QString readWalletPassword(bool fromUserNameOnly = false);
